summaryrefslogtreecommitdiffstats
path: root/src/viewcontainer.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/viewcontainer.h')
-rw-r--r--src/viewcontainer.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/src/viewcontainer.h b/src/viewcontainer.h
index e31aac2..50458b6 100644
--- a/src/viewcontainer.h
+++ b/src/viewcontainer.h
@@ -58,7 +58,7 @@ public:
Bottom
};
- ViewArea( TQWidget *tqparent, ViewContainer *viewContainer, int id, const char *name = 0 );
+ ViewArea( TQWidget *parent, ViewContainer *viewContainer, int id, const char *name = 0 );
~ViewArea();
ViewContainer *viewContainer() const { return p_viewContainer; }
@@ -117,10 +117,10 @@ Q_OBJECT
public:
/**
* Constructs a new ViewContainer, along with a default ViewArea ready for
* parenting a View, with an id of 0. tqparent is only used if ktechlab is
* null; otherwise the tqparent widget is ktechlab's tabWidget()
*/
- ViewContainer( const TQString & caption, KTechlab * ktechlab, TQWidget * tqparent = 0 );
+ ViewContainer( const TQString & caption, KTechlab * ktechlab, TQWidget * parent = 0 );
~ViewContainer();
/**
@@ -149,7 +149,7 @@ public:
*/
bool closeViewArea( uint id );
/**
* Creates a view area (tqparent TQWidget, splitter et al) ready for inclusion
* of a view.
* @param relativeViewArea the viewarea to position the new viewarea next to, if -1 then is taken to be the active view area
* @param position Top, Right, Bottom or Left of given relativeViewArea
@@ -117,10 +117,10 @@ Q_OBJECT
/**
* Constructs a new ViewContainer, along with a default ViewArea ready for
- * parenting a View, with an id of 0. tqparent is only used if ktechlab is
- * null; otherwise the tqparent widget is ktechlab's tabWidget()
+ * parenting a View, with an id of 0. parent is only used if ktechlab is
+ * null; otherwise the parent widget is ktechlab's tabWidget()
*/
@@ -149,7 +149,7 @@ public:
bool closeViewArea( uint id );
/**
- * Creates a view area (tqparent TQWidget, splitter et al) ready for inclusion
+ * Creates a view area (parent TQWidget, splitter et al) ready for inclusion
* of a view.
* @param relativeViewArea the viewarea to position the new viewarea next to, if -1 then is taken to be the active view area